# -*- coding: utf-8 -*-

"""
    mundiapi.models.update_address_request

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""


class UpdateAddressRequest(object):

    """Implementation of the 'UpdateAddressRequest' model.

    Request for updating an address

    Attributes:
        number (string): Number
        complement (string): Complement
        metadata (dict<object, string>): Metadata
        line_2 (string): Line 2 for address

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "number":'number',
        "complement":'complement',
        "metadata":'metadata',
        "line_2":'line_2'
    }

    def __init__(self,
                 number=None,
                 complement=None,
                 metadata=None,
                 line_2=None):
        """Constructor for the UpdateAddressRequest class"""

        # Initialize members of the class
        self.number = number
        self.complement = complement
        self.metadata = metadata
        self.line_2 = line_2


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        number = dictionary.get('number')
        complement = dictionary.get('complement')
        metadata = dictionary.get('metadata')
        line_2 = dictionary.get('line_2')

        # Return an object of this model
        return cls(number,
                   complement,
                   metadata,
                   line_2)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.get_period_response

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
from mundiapi.api_helper import APIHelper
import mundiapi.models.get_subscription_response

class GetPeriodResponse(object):

    """Implementation of the 'GetPeriodResponse' model.

    Response object for getting a period

    Attributes:
        start_at (datetime): TODO: type description here.
        end_at (datetime): TODO: type description here.
        id (string): TODO: type description here.
        billing_at (datetime): TODO: type description here.
        subscription (GetSubscriptionResponse): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "start_at":'start_at',
        "end_at":'end_at',
        "id":'id',
        "billing_at":'billing_at',
        "subscription":'subscription'
    }

    def __init__(self,
                 start_at=None,
                 end_at=None,
                 id=None,
                 billing_at=None,
                 subscription=None):
        """Constructor for the GetPeriodResponse class"""

        # Initialize members of the class
        self.start_at = APIHelper.RFC3339DateTime(start_at) if start_at else None
        self.end_at = APIHelper.RFC3339DateTime(end_at) if end_at else None
        self.id = id
        self.billing_at = APIHelper.RFC3339DateTime(billing_at) if billing_at else None
        self.subscription = subscription


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        start_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("start_at")).datetime if dictionary.get("start_at") else None
        end_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("end_at")).datetime if dictionary.get("end_at") else None
        id = dictionary.get('id')
        billing_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("billing_at")).datetime if dictionary.get("billing_at") else None
        subscription = mundiapi.models.get_subscription_response.GetSubscriptionResponse.from_dictionary(dictionary.get('subscription')) if dictionary.get('subscription') else None

        # Return an object of this model
        return cls(start_at,
                   end_at,
                   id,
                   billing_at,
                   subscription)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.get_checkout_boleto_payment_response

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
from mundiapi.api_helper import APIHelper

class GetCheckoutBoletoPaymentResponse(object):

    """Implementation of the 'GetCheckoutBoletoPaymentResponse' model.

    TODO: type model description here.

    Attributes:
        due_at (datetime): Data de vencimento do boleto
        instructions (string): Instruções do boleto

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "due_at":'due_at',
        "instructions":'instructions'
    }

    def __init__(self,
                 due_at=None,
                 instructions=None):
        """Constructor for the GetCheckoutBoletoPaymentResponse class"""

        # Initialize members of the class
        self.due_at = APIHelper.RFC3339DateTime(due_at) if due_at else None
        self.instructions = instructions


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        due_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("due_at")).datetime if dictionary.get("due_at") else None
        instructions = dictionary.get('instructions')

        # Return an object of this model
        return cls(due_at,
                   instructions)





# -*- coding: utf-8 -*-

"""
   mundiapi.http.auth.basic_auth

   This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""

import base64
from ...configuration import Configuration

class BasicAuth:

    @staticmethod
    def apply(http_request):
        """ Add basic authentication to the request.

        Args:
            http_request (HttpRequest): The HttpRequest object to which 
                authentication will be added.

        """
        username = Configuration.basic_auth_user_name
        password = Configuration.basic_auth_password
        joined = "{}:{}".format(username, password)
        encoded = base64.b64encode(str.encode(joined)).decode('iso-8859-1')
        header_value = "Basic {}".format(encoded)
        http_request.headers["Authorization"] = header_value


# -*- coding: utf-8 -*-

"""
    mundiapi.models.create_plan_item_request

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
import mundiapi.models.create_pricing_scheme_request

class CreatePlanItemRequest(object):

    """Implementation of the 'CreatePlanItemRequest' model.

    Request for creating a plan item

    Attributes:
        name (string): Item name
        pricing_scheme (CreatePricingSchemeRequest): Item's pricing scheme
        id (string): Item's id
        description (string): Item's description
        cycles (int): Number of cycles where the item will be charged
        quantity (int): Quantity

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name":'name',
        "pricing_scheme":'pricing_scheme',
        "id":'id',
        "description":'description',
        "cycles":'cycles',
        "quantity":'quantity'
    }

    def __init__(self,
                 name=None,
                 pricing_scheme=None,
                 id=None,
                 description=None,
                 cycles=None,
                 quantity=None):
        """Constructor for the CreatePlanItemRequest class"""

        # Initialize members of the class
        self.name = name
        self.pricing_scheme = pricing_scheme
        self.id = id
        self.description = description
        self.cycles = cycles
        self.quantity = quantity


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get('name')
        pricing_scheme = mundiapi.models.create_pricing_scheme_request.CreatePricingSchemeRequest.from_dictionary(dictionary.get('pricing_scheme')) if dictionary.get('pricing_scheme') else None
        id = dictionary.get('id')
        description = dictionary.get('description')
        cycles = dictionary.get('cycles')
        quantity = dictionary.get('quantity')

        # Return an object of this model
        return cls(name,
                   pricing_scheme,
                   id,
                   description,
                   cycles,
                   quantity)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.get_address_response

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
from mundiapi.api_helper import APIHelper
import mundiapi.models.get_customer_response

class GetAddressResponse(object):

    """Implementation of the 'GetAddressResponse' model.

    Response object for getting an Address

    Attributes:
        id (string): TODO: type description here.
        street (string): TODO: type description here.
        number (string): TODO: type description here.
        complement (string): TODO: type description here.
        zip_code (string): TODO: type description here.
        neighborhood (string): TODO: type description here.
        city (string): TODO: type description here.
        state (string): TODO: type description here.
        country (string): TODO: type description here.
        status (string): TODO: type description here.
        created_at (datetime): TODO: type description here.
        updated_at (datetime): TODO: type description here.
        customer (GetCustomerResponse): TODO: type description here.
        metadata (dict<object, string>): TODO: type description here.
        line_1 (string): Line 1 for address
        line_2 (string): Line 2 for address
        deleted_at (datetime): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id":'id',
        "street":'street',
        "number":'number',
        "complement":'complement',
        "zip_code":'zip_code',
        "neighborhood":'neighborhood',
        "city":'city',
        "state":'state',
        "country":'country',
        "status":'status',
        "created_at":'created_at',
        "updated_at":'updated_at',
        "customer":'customer',
        "metadata":'metadata',
        "line_1":'line_1',
        "line_2":'line_2',
        "deleted_at":'deleted_at'
    }

    def __init__(self,
                 id=None,
                 street=None,
                 number=None,
                 complement=None,
                 zip_code=None,
                 neighborhood=None,
                 city=None,
                 state=None,
                 country=None,
                 status=None,
                 created_at=None,
                 updated_at=None,
                 customer=None,
                 metadata=None,
                 line_1=None,
                 line_2=None,
                 deleted_at=None):
        """Constructor for the GetAddressResponse class"""

        # Initialize members of the class
        self.id = id
        self.street = street
        self.number = number
        self.complement = complement
        self.zip_code = zip_code
        self.neighborhood = neighborhood
        self.city = city
        self.state = state
        self.country = country
        self.status = status
        self.created_at = APIHelper.RFC3339DateTime(created_at) if created_at else None
        self.updated_at = APIHelper.RFC3339DateTime(updated_at) if updated_at else None
        self.customer = customer
        self.metadata = metadata
        self.line_1 = line_1
        self.line_2 = line_2
        self.deleted_at = APIHelper.RFC3339DateTime(deleted_at) if deleted_at else None


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('id')
        street = dictionary.get('street')
        number = dictionary.get('number')
        complement = dictionary.get('complement')
        zip_code = dictionary.get('zip_code')
        neighborhood = dictionary.get('neighborhood')
        city = dictionary.get('city')
        state = dictionary.get('state')
        country = dictionary.get('country')
        status = dictionary.get('status')
        created_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("created_at")).datetime if dictionary.get("created_at") else None
        updated_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("updated_at")).datetime if dictionary.get("updated_at") else None
        customer = mundiapi.models.get_customer_response.GetCustomerResponse.from_dictionary(dictionary.get('customer')) if dictionary.get('customer') else None
        metadata = dictionary.get('metadata')
        line_1 = dictionary.get('line_1')
        line_2 = dictionary.get('line_2')
        deleted_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("deleted_at")).datetime if dictionary.get("deleted_at") else None

        # Return an object of this model
        return cls(id,
                   street,
                   number,
                   complement,
                   zip_code,
                   neighborhood,
                   city,
                   state,
                   country,
                   status,
                   created_at,
                   updated_at,
                   customer,
                   metadata,
                   line_1,
                   line_2,
                   deleted_at)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.update_price_bracket_request

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""


class UpdatePriceBracketRequest(object):

    """Implementation of the 'UpdatePriceBracketRequest' model.

    Request for updating a price bracket

    Attributes:
        start_quantity (int): Start quantity of the bracket
        price (int): Price
        end_quantity (int): End quantity of the bracket
        overage_price (int): Overage price

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "start_quantity":'start_quantity',
        "price":'price',
        "end_quantity":'end_quantity',
        "overage_price":'overage_price'
    }

    def __init__(self,
                 start_quantity=None,
                 price=None,
                 end_quantity=None,
                 overage_price=None):
        """Constructor for the UpdatePriceBracketRequest class"""

        # Initialize members of the class
        self.start_quantity = start_quantity
        self.price = price
        self.end_quantity = end_quantity
        self.overage_price = overage_price


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        start_quantity = dictionary.get('start_quantity')
        price = dictionary.get('price')
        end_quantity = dictionary.get('end_quantity')
        overage_price = dictionary.get('overage_price')

        # Return an object of this model
        return cls(start_quantity,
                   price,
                   end_quantity,
                   overage_price)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.update_order_item_request

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""


class UpdateOrderItemRequest(object):

    """Implementation of the 'UpdateOrderItemRequest' model.

    Update Order item Request

    Attributes:
        amount (int): TODO: type description here.
        description (string): TODO: type description here.
        quantity (int): TODO: type description here.
        category (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "amount":'amount',
        "description":'description',
        "quantity":'quantity',
        "category":'category'
    }

    def __init__(self,
                 amount=None,
                 description=None,
                 quantity=None,
                 category=None):
        """Constructor for the UpdateOrderItemRequest class"""

        # Initialize members of the class
        self.amount = amount
        self.description = description
        self.quantity = quantity
        self.category = category


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        amount = dictionary.get('amount')
        description = dictionary.get('description')
        quantity = dictionary.get('quantity')
        category = dictionary.get('category')

        # Return an object of this model
        return cls(amount,
                   description,
                   quantity,
                   category)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.create_order_request

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
import mundiapi.models.create_order_item_request
import mundiapi.models.create_customer_request
import mundiapi.models.create_payment_request
import mundiapi.models.create_shipping_request
import mundiapi.models.create_location_request
import mundiapi.models.create_device_request

class CreateOrderRequest(object):

    """Implementation of the 'CreateOrderRequest' model.

    Request for creating an order

    Attributes:
        items (list of CreateOrderItemRequest): Items
        customer (CreateCustomerRequest): Customer
        payments (list of CreatePaymentRequest): Payment data
        code (string): The order code
        customer_id (string): The customer id
        shipping (CreateShippingRequest): Shipping data
        metadata (dict<object, string>): Metadata
        closed (bool): TODO: type description here.
        antifraud_enabled (bool): Defines whether the order will go through
            anti-fraud
        ip (string): Ip address
        session_id (string): Session id
        location (CreateLocationRequest): Request's location
        device (CreateDeviceRequest): Device's informations

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "items":'items',
        "customer":'customer',
        "payments":'payments',
        "code":'code',
        "customer_id":'customer_id',
        "shipping":'shipping',
        "metadata":'metadata',
        "closed":'closed',
        "antifraud_enabled":'antifraud_enabled',
        "ip":'ip',
        "session_id":'session_id',
        "location":'location',
        "device":'device'
    }

    def __init__(self,
                 items=None,
                 customer=None,
                 payments=None,
                 code=None,
                 customer_id=None,
                 shipping=None,
                 metadata=None,
                 closed=True,
                 antifraud_enabled=None,
                 ip=None,
                 session_id=None,
                 location=None,
                 device=None):
        """Constructor for the CreateOrderRequest class"""

        # Initialize members of the class
        self.items = items
        self.customer = customer
        self.payments = payments
        self.code = code
        self.customer_id = customer_id
        self.shipping = shipping
        self.metadata = metadata
        self.closed = closed
        self.antifraud_enabled = antifraud_enabled
        self.ip = ip
        self.session_id = session_id
        self.location = location
        self.device = device


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        items = None
        if dictionary.get('items') != None:
            items = list()
            for structure in dictionary.get('items'):
                items.append(mundiapi.models.create_order_item_request.CreateOrderItemRequest.from_dictionary(structure))
        customer = mundiapi.models.create_customer_request.CreateCustomerRequest.from_dictionary(dictionary.get('customer')) if dictionary.get('customer') else None
        payments = None
        if dictionary.get('payments') != None:
            payments = list()
            for structure in dictionary.get('payments'):
                payments.append(mundiapi.models.create_payment_request.CreatePaymentRequest.from_dictionary(structure))
        code = dictionary.get('code')
        customer_id = dictionary.get('customer_id')
        shipping = mundiapi.models.create_shipping_request.CreateShippingRequest.from_dictionary(dictionary.get('shipping')) if dictionary.get('shipping') else None
        metadata = dictionary.get('metadata')
        closed = dictionary.get("closed") if dictionary.get("closed") else True
        antifraud_enabled = dictionary.get('antifraud_enabled')
        ip = dictionary.get('ip')
        session_id = dictionary.get('session_id')
        location = mundiapi.models.create_location_request.CreateLocationRequest.from_dictionary(dictionary.get('location')) if dictionary.get('location') else None
        device = mundiapi.models.create_device_request.CreateDeviceRequest.from_dictionary(dictionary.get('device')) if dictionary.get('device') else None

        # Return an object of this model
        return cls(items,
                   customer,
                   payments,
                   code,
                   customer_id,
                   shipping,
                   metadata,
                   closed,
                   antifraud_enabled,
                   ip,
                   session_id,
                   location,
                   device)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.create_credit_card_payment_request

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
import mundiapi.models.create_card_request

class CreateCreditCardPaymentRequest(object):

    """Implementation of the 'CreateCreditCardPaymentRequest' model.

    The settings for creating a credit card payment

    Attributes:
        installments (int): Number of installments
        statement_descriptor (string): The text that will be shown on the
            credit card's statement
        card (CreateCardRequest): Credit card data
        retries (int): Number of retries
        update_subscription_card (bool): Indicates if the card from the
            subscription must be updated
        card_id (string): The credit card id
        card_token (string): TODO: type description here.
        recurrence (bool): Indicates a recurrence
        extended_limit_enabled (bool): Indicates whether the extended label
            (private label) is enabled
        extended_limit_code (string): Extended Limit Code
        capture (bool): Indicates if the operation should be only
            authorization or auth and capture.
        merchant_category_code (long|int): Customer business segment code

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "installments":'installments',
        "statement_descriptor":'statement_descriptor',
        "card":'card',
        "retries":'retries',
        "update_subscription_card":'update_subscription_card',
        "card_id":'card_id',
        "card_token":'card_token',
        "recurrence":'recurrence',
        "extended_limit_enabled":'extended_limit_enabled',
        "extended_limit_code":'extended_limit_code',
        "capture":'capture',
        "merchant_category_code":'merchant_category_code'
    }

    def __init__(self,
                 installments=1,
                 statement_descriptor=None,
                 card=None,
                 retries=None,
                 update_subscription_card=None,
                 card_id=None,
                 card_token=None,
                 recurrence=None,
                 extended_limit_enabled=None,
                 extended_limit_code=None,
                 capture=True,
                 merchant_category_code=None):
        """Constructor for the CreateCreditCardPaymentRequest class"""

        # Initialize members of the class
        self.installments = installments
        self.statement_descriptor = statement_descriptor
        self.card = card
        self.retries = retries
        self.update_subscription_card = update_subscription_card
        self.card_id = card_id
        self.card_token = card_token
        self.recurrence = recurrence
        self.extended_limit_enabled = extended_limit_enabled
        self.extended_limit_code = extended_limit_code
        self.capture = capture
        self.merchant_category_code = merchant_category_code


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        installments = dictionary.get("installments") if dictionary.get("installments") else 1
        statement_descriptor = dictionary.get('statement_descriptor')
        card = mundiapi.models.create_card_request.CreateCardRequest.from_dictionary(dictionary.get('card')) if dictionary.get('card') else None
        retries = dictionary.get('retries')
        update_subscription_card = dictionary.get('update_subscription_card')
        card_id = dictionary.get('card_id')
        card_token = dictionary.get('card_token')
        recurrence = dictionary.get('recurrence')
        extended_limit_enabled = dictionary.get('extended_limit_enabled')
        extended_limit_code = dictionary.get('extended_limit_code')
        capture = dictionary.get("capture") if dictionary.get("capture") else True
        merchant_category_code = dictionary.get('merchant_category_code')

        # Return an object of this model
        return cls(installments,
                   statement_descriptor,
                   card,
                   retries,
                   update_subscription_card,
                   card_id,
                   card_token,
                   recurrence,
                   extended_limit_enabled,
                   extended_limit_code,
                   capture,
                   merchant_category_code)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.update_card_request

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
import mundiapi.models.create_address_request

class UpdateCardRequest(object):

    """Implementation of the 'UpdateCardRequest' model.

    Request for updating a card

    Attributes:
        holder_name (string): Holder name
        exp_month (int): Expiration month
        exp_year (int): Expiration year
        billing_address_id (string): Id of the address to be used as billing
            address
        billing_address (CreateAddressRequest): Billing address
        metadata (dict<object, string>): Metadata

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "holder_name":'holder_name',
        "exp_month":'exp_month',
        "exp_year":'exp_year',
        "billing_address_id":'billing_address_id',
        "billing_address":'billing_address',
        "metadata":'metadata'
    }

    def __init__(self,
                 holder_name=None,
                 exp_month=None,
                 exp_year=None,
                 billing_address_id=None,
                 billing_address=None,
                 metadata=None):
        """Constructor for the UpdateCardRequest class"""

        # Initialize members of the class
        self.holder_name = holder_name
        self.exp_month = exp_month
        self.exp_year = exp_year
        self.billing_address_id = billing_address_id
        self.billing_address = billing_address
        self.metadata = metadata


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        holder_name = dictionary.get('holder_name')
        exp_month = dictionary.get('exp_month')
        exp_year = dictionary.get('exp_year')
        billing_address_id = dictionary.get('billing_address_id')
        billing_address = mundiapi.models.create_address_request.CreateAddressRequest.from_dictionary(dictionary.get('billing_address')) if dictionary.get('billing_address') else None
        metadata = dictionary.get('metadata')

        # Return an object of this model
        return cls(holder_name,
                   exp_month,
                   exp_year,
                   billing_address_id,
                   billing_address,
                   metadata)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.get_transfer_response

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
from mundiapi.api_helper import APIHelper
import mundiapi.models.get_bank_account_response

class GetTransferResponse(object):

    """Implementation of the 'GetTransferResponse' model.

    Transfer response

    Attributes:
        id (string): Id
        amount (int): Transfer amount
        status (string): Transfer status
        created_at (datetime): Transfer creation date
        updated_at (datetime): Transfer last update date
        bank_account (GetBankAccountResponse): Bank account
        metadata (dict<object, string>): Metadata

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id":'id',
        "amount":'amount',
        "status":'status',
        "created_at":'created_at',
        "updated_at":'updated_at',
        "bank_account":'bank_account',
        "metadata":'metadata'
    }

    def __init__(self,
                 id=None,
                 amount=None,
                 status=None,
                 created_at=None,
                 updated_at=None,
                 bank_account=None,
                 metadata=None):
        """Constructor for the GetTransferResponse class"""

        # Initialize members of the class
        self.id = id
        self.amount = amount
        self.status = status
        self.created_at = APIHelper.RFC3339DateTime(created_at) if created_at else None
        self.updated_at = APIHelper.RFC3339DateTime(updated_at) if updated_at else None
        self.bank_account = bank_account
        self.metadata = metadata


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('id')
        amount = dictionary.get('amount')
        status = dictionary.get('status')
        created_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("created_at")).datetime if dictionary.get("created_at") else None
        updated_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("updated_at")).datetime if dictionary.get("updated_at") else None
        bank_account = mundiapi.models.get_bank_account_response.GetBankAccountResponse.from_dictionary(dictionary.get('bank_account')) if dictionary.get('bank_account') else None
        metadata = dictionary.get('metadata')

        # Return an object of this model
        return cls(id,
                   amount,
                   status,
                   created_at,
                   updated_at,
                   bank_account,
                   metadata)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.create_address_request

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""


class CreateAddressRequest(object):

    """Implementation of the 'CreateAddressRequest' model.

    Request for creating a new Address

    Attributes:
        street (string): Street
        number (string): Number
        zip_code (string): The zip code containing only numbers. No special
            characters or spaces.
        neighborhood (string): Neighborhood
        city (string): City
        state (string): State
        country (string): Country. Must be entered using ISO 3166-1 alpha-2
            format. See https://pt.wikipedia.org/wiki/ISO_3166-1_alfa-2
        complement (string): Complement
        metadata (dict<object, string>): Metadata
        line_1 (string): Line 1 for address
        line_2 (string): Line 2 for address

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "street":'street',
        "number":'number',
        "zip_code":'zip_code',
        "neighborhood":'neighborhood',
        "city":'city',
        "state":'state',
        "country":'country',
        "complement":'complement',
        "metadata":'metadata',
        "line_1":'line_1',
        "line_2":'line_2'
    }

    def __init__(self,
                 street=None,
                 number=None,
                 zip_code=None,
                 neighborhood=None,
                 city=None,
                 state=None,
                 country=None,
                 complement=None,
                 metadata=None,
                 line_1=None,
                 line_2=None):
        """Constructor for the CreateAddressRequest class"""

        # Initialize members of the class
        self.street = street
        self.number = number
        self.zip_code = zip_code
        self.neighborhood = neighborhood
        self.city = city
        self.state = state
        self.country = country
        self.complement = complement
        self.metadata = metadata
        self.line_1 = line_1
        self.line_2 = line_2


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        street = dictionary.get('street')
        number = dictionary.get('number')
        zip_code = dictionary.get('zip_code')
        neighborhood = dictionary.get('neighborhood')
        city = dictionary.get('city')
        state = dictionary.get('state')
        country = dictionary.get('country')
        complement = dictionary.get('complement')
        metadata = dictionary.get('metadata')
        line_1 = dictionary.get('line_1')
        line_2 = dictionary.get('line_2')

        # Return an object of this model
        return cls(street,
                   number,
                   zip_code,
                   neighborhood,
                   city,
                   state,
                   country,
                   complement,
                   metadata,
                   line_1,
                   line_2)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.get_bank_account_response

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
from mundiapi.api_helper import APIHelper
import mundiapi.models.get_recipient_response

class GetBankAccountResponse(object):

    """Implementation of the 'GetBankAccountResponse' model.

    TODO: type model description here.

    Attributes:
        id (string): Id
        holder_name (string): Holder name
        holder_type (string): Holder type
        bank (string): Bank
        branch_number (string): Branch number
        branch_check_digit (string): Branch check digit
        account_number (string): Account number
        account_check_digit (string): Account check digit
        mtype (string): Bank account type
        status (string): Bank account status
        created_at (datetime): Creation date
        updated_at (datetime): Last update date
        deleted_at (datetime): Deletion date
        recipient (GetRecipientResponse): Recipient
        metadata (dict<object, string>): Metadata

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id":'id',
        "holder_name":'holder_name',
        "holder_type":'holder_type',
        "bank":'bank',
        "branch_number":'branch_number',
        "branch_check_digit":'branch_check_digit',
        "account_number":'account_number',
        "account_check_digit":'account_check_digit',
        "mtype":'type',
        "status":'status',
        "created_at":'created_at',
        "updated_at":'updated_at',
        "deleted_at":'deleted_at',
        "recipient":'recipient',
        "metadata":'metadata'
    }

    def __init__(self,
                 id=None,
                 holder_name=None,
                 holder_type=None,
                 bank=None,
                 branch_number=None,
                 branch_check_digit=None,
                 account_number=None,
                 account_check_digit=None,
                 mtype=None,
                 status=None,
                 created_at=None,
                 updated_at=None,
                 deleted_at=None,
                 recipient=None,
                 metadata=None):
        """Constructor for the GetBankAccountResponse class"""

        # Initialize members of the class
        self.id = id
        self.holder_name = holder_name
        self.holder_type = holder_type
        self.bank = bank
        self.branch_number = branch_number
        self.branch_check_digit = branch_check_digit
        self.account_number = account_number
        self.account_check_digit = account_check_digit
        self.mtype = mtype
        self.status = status
        self.created_at = APIHelper.RFC3339DateTime(created_at) if created_at else None
        self.updated_at = APIHelper.RFC3339DateTime(updated_at) if updated_at else None
        self.deleted_at = APIHelper.RFC3339DateTime(deleted_at) if deleted_at else None
        self.recipient = recipient
        self.metadata = metadata


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('id')
        holder_name = dictionary.get('holder_name')
        holder_type = dictionary.get('holder_type')
        bank = dictionary.get('bank')
        branch_number = dictionary.get('branch_number')
        branch_check_digit = dictionary.get('branch_check_digit')
        account_number = dictionary.get('account_number')
        account_check_digit = dictionary.get('account_check_digit')
        mtype = dictionary.get('type')
        status = dictionary.get('status')
        created_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("created_at")).datetime if dictionary.get("created_at") else None
        updated_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("updated_at")).datetime if dictionary.get("updated_at") else None
        deleted_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("deleted_at")).datetime if dictionary.get("deleted_at") else None
        recipient = mundiapi.models.get_recipient_response.GetRecipientResponse.from_dictionary(dictionary.get('recipient')) if dictionary.get('recipient') else None
        metadata = dictionary.get('metadata')

        # Return an object of this model
        return cls(id,
                   holder_name,
                   holder_type,
                   bank,
                   branch_number,
                   branch_check_digit,
                   account_number,
                   account_check_digit,
                   mtype,
                   status,
                   created_at,
                   updated_at,
                   deleted_at,
                   recipient,
                   metadata)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.get_balance_response

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
import mundiapi.models.get_recipient_response

class GetBalanceResponse(object):

    """Implementation of the 'GetBalanceResponse' model.

    Balance

    Attributes:
        currency (string): Currency
        available_amount (int): Amount available for transferring
        recipient (GetRecipientResponse): Recipient

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "currency":'currency',
        "available_amount":'available_amount',
        "recipient":'recipient'
    }

    def __init__(self,
                 currency=None,
                 available_amount=None,
                 recipient=None):
        """Constructor for the GetBalanceResponse class"""

        # Initialize members of the class
        self.currency = currency
        self.available_amount = available_amount
        self.recipient = recipient


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        currency = dictionary.get('currency')
        available_amount = dictionary.get('available_amount')
        recipient = mundiapi.models.get_recipient_response.GetRecipientResponse.from_dictionary(dictionary.get('recipient')) if dictionary.get('recipient') else None

        # Return an object of this model
        return cls(currency,
                   available_amount,
                   recipient)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.create_order_item_request

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
import mundiapi.models.create_seller_request

class CreateOrderItemRequest(object):

    """Implementation of the 'CreateOrderItemRequest' model.

    Request for creating an order item

    Attributes:
        amount (int): Amount
        description (string): Description
        quantity (int): Quantity
        category (string): Category
        seller (CreateSellerRequest): Item seller
        seller_id (string): seller identificator

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "amount":'amount',
        "description":'description',
        "quantity":'quantity',
        "category":'category',
        "seller":'seller',
        "seller_id":'seller_id'
    }

    def __init__(self,
                 amount=None,
                 description=None,
                 quantity=None,
                 category=None,
                 seller=None,
                 seller_id=None):
        """Constructor for the CreateOrderItemRequest class"""

        # Initialize members of the class
        self.amount = amount
        self.description = description
        self.quantity = quantity
        self.category = category
        self.seller = seller
        self.seller_id = seller_id


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        amount = dictionary.get('amount')
        description = dictionary.get('description')
        quantity = dictionary.get('quantity')
        category = dictionary.get('category')
        seller = mundiapi.models.create_seller_request.CreateSellerRequest.from_dictionary(dictionary.get('seller')) if dictionary.get('seller') else None
        seller_id = dictionary.get('seller_id')

        # Return an object of this model
        return cls(amount,
                   description,
                   quantity,
                   category,
                   seller,
                   seller_id)





# -*- coding: utf-8 -*-

"""
    mundiapi.controllers.recipients_controller

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from .base_controller import BaseController
from ..api_helper import APIHelper
from ..configuration import Configuration
from ..http.auth.basic_auth import BasicAuth
from ..models.get_recipient_response import GetRecipientResponse
from ..models.get_transfer_response import GetTransferResponse
from ..models.list_transfer_response import ListTransferResponse
from ..models.get_anticipation_response import GetAnticipationResponse
from ..models.get_anticipation_limit_response import GetAnticipationLimitResponse
from ..models.list_anticipation_response import ListAnticipationResponse
from ..models.list_recipient_response import ListRecipientResponse
from ..models.get_balance_response import GetBalanceResponse

class RecipientsController(BaseController):

    """A Controller to access Endpoints in the mundiapi API."""


    def update_recipient_metadata(self,
                                  recipient_id,
                                  request):
        """Does a PATCH request to /recipients/{recipient_id}/metadata.

        Updates recipient metadata

        Args:
            recipient_id (string): Recipient id
            request (UpdateMetadataRequest): Metadata

        Returns:
            GetRecipientResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.base_uri
        _query_builder += '/recipients/{recipient_id}/metadata'
        _query_builder = APIHelper.append_url_with_template_parameters(_query_builder, { 
            'recipient_id': recipient_id
        })
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.patch(_query_url, headers=_headers, parameters=APIHelper.json_serialize(request))
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetRecipientResponse.from_dictionary)

    def get_transfer(self,
                     recipient_id,
                     transfer_id):
        """Does a GET request to /recipients/{recipient_id}/transfers/{transfer_id}.

        Gets a transfer

        Args:
            recipient_id (string): Recipient id
            transfer_id (string): Transfer id

        Returns:
            GetTransferResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.base_uri
        _query_builder += '/recipients/{recipient_id}/transfers/{transfer_id}'
        _query_builder = APIHelper.append_url_with_template_parameters(_query_builder, { 
            'recipient_id': recipient_id,
            'transfer_id': transfer_id
        })
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetTransferResponse.from_dictionary)

    def get_transfers(self,
                      recipient_id,
                      page=None,
                      size=None,
                      status=None,
                      created_since=None,
                      created_until=None):
        """Does a GET request to /recipients/{recipient_id}/transfers.

        Gets a paginated list of transfers for the recipient

        Args:
            recipient_id (string): Recipient id
            page (int, optional): Page number
            size (int, optional): Page size
            status (string, optional): Filter for transfer status
            created_since (datetime, optional): Filter for start range of
                transfer creation date
            created_until (datetime, optional): Filter for end range of
                transfer creation date

        Returns:
            ListTransferResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.base_uri
        _query_builder += '/recipients/{recipient_id}/transfers'
        _query_builder = APIHelper.append_url_with_template_parameters(_query_builder, { 
            'recipient_id': recipient_id
        })
        _query_parameters = {
            'page': page,
            'size': size,
            'status': status,
            'created_since': APIHelper.RFC3339DateTime(created_since),
            'created_until': APIHelper.RFC3339DateTime(created_until)
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, ListTransferResponse.from_dictionary)

    def create_anticipation(self,
                            recipient_id,
                            request):
        """Does a POST request to /recipients/{recipient_id}/anticipations.

        Creates an anticipation

        Args:
            recipient_id (string): Recipient id
            request (CreateAnticipationRequest): Anticipation data

        Returns:
            GetAnticipationResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.base_uri
        _query_builder += '/recipients/{recipient_id}/anticipations'
        _query_builder = APIHelper.append_url_with_template_parameters(_query_builder, { 
            'recipient_id': recipient_id
        })
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(request))
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetAnticipationResponse.from_dictionary)

    def get_anticipation(self,
                         recipient_id,
                         anticipation_id):
        """Does a GET request to /recipients/{recipient_id}/anticipations/{anticipation_id}.

        Gets an anticipation

        Args:
            recipient_id (string): Recipient id
            anticipation_id (string): Anticipation id

        Returns:
            GetAnticipationResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.base_uri
        _query_builder += '/recipients/{recipient_id}/anticipations/{anticipation_id}'
        _query_builder = APIHelper.append_url_with_template_parameters(_query_builder, { 
            'recipient_id': recipient_id,
            'anticipation_id': anticipation_id
        })
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetAnticipationResponse.from_dictionary)

    def get_anticipation_limits(self,
                                recipient_id,
                                timeframe,
                                payment_date):
        """Does a GET request to /recipients/{recipient_id}/anticipation_limits.

        Gets the anticipation limits for a recipient

        Args:
            recipient_id (string): Recipient id
            timeframe (string): Timeframe
            payment_date (datetime): Anticipation payment date

        Returns:
            GetAnticipationLimitResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.base_uri
        _query_builder += '/recipients/{recipient_id}/anticipation_limits'
        _query_builder = APIHelper.append_url_with_template_parameters(_query_builder, { 
            'recipient_id': recipient_id
        })
        _query_parameters = {
            'timeframe': timeframe,
            'payment_date': APIHelper.RFC3339DateTime(payment_date)
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetAnticipationLimitResponse.from_dictionary)

    def get_anticipations(self,
                          recipient_id,
                          page=None,
                          size=None,
                          status=None,
                          timeframe=None,
                          payment_date_since=None,
                          payment_date_until=None,
                          created_since=None,
                          created_until=None):
        """Does a GET request to /recipients/{recipient_id}/anticipations.

        Retrieves a paginated list of anticipations from a recipient

        Args:
            recipient_id (string): Recipient id
            page (int, optional): Page number
            size (int, optional): Page size
            status (string, optional): Filter for anticipation status
            timeframe (string, optional): Filter for anticipation timeframe
            payment_date_since (datetime, optional): Filter for start range
                for anticipation payment date
            payment_date_until (datetime, optional): Filter for end range for
                anticipation payment date
            created_since (datetime, optional): Filter for start range for
                anticipation creation date
            created_until (datetime, optional): Filter for end range for
                anticipation creation date

        Returns:
            ListAnticipationResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.base_uri
        _query_builder += '/recipients/{recipient_id}/anticipations'
        _query_builder = APIHelper.append_url_with_template_parameters(_query_builder, { 
            'recipient_id': recipient_id
        })
        _query_parameters = {
            'page': page,
            'size': size,
            'status': status,
            'timeframe': timeframe,
            'payment_date_since': APIHelper.RFC3339DateTime(payment_date_since),
            'payment_date_until': APIHelper.RFC3339DateTime(payment_date_until),
            'created_since': APIHelper.RFC3339DateTime(created_since),
            'created_until': APIHelper.RFC3339DateTime(created_until)
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, ListAnticipationResponse.from_dictionary)

    def update_recipient(self,
                         recipient_id,
                         request):
        """Does a PUT request to /recipients/{recipient_id}.

        Updates a recipient

        Args:
            recipient_id (string): Recipient id
            request (UpdateRecipientRequest): Recipient data

        Returns:
            GetRecipientResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.base_uri
        _query_builder += '/recipients/{recipient_id}'
        _query_builder = APIHelper.append_url_with_template_parameters(_query_builder, { 
            'recipient_id': recipient_id
        })
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(request))
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetRecipientResponse.from_dictionary)

    def update_recipient_default_bank_account(self,
                                              recipient_id,
                                              request):
        """Does a PATCH request to /recipients/{recipient_id}/default-bank-account.

        Updates the default bank account from a recipient

        Args:
            recipient_id (string): Recipient id
            request (UpdateRecipientBankAccountRequest): Bank account data

        Returns:
            GetRecipientResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.base_uri
        _query_builder += '/recipients/{recipient_id}/default-bank-account'
        _query_builder = APIHelper.append_url_with_template_parameters(_query_builder, { 
            'recipient_id': recipient_id
        })
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.patch(_query_url, headers=_headers, parameters=APIHelper.json_serialize(request))
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetRecipientResponse.from_dictionary)

    def get_recipient(self,
                      recipient_id):
        """Does a GET request to /recipients/{recipient_id}.

        Retrieves recipient information

        Args:
            recipient_id (string): Recipiend id

        Returns:
            GetRecipientResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.base_uri
        _query_builder += '/recipients/{recipient_id}'
        _query_builder = APIHelper.append_url_with_template_parameters(_query_builder, { 
            'recipient_id': recipient_id
        })
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetRecipientResponse.from_dictionary)

    def get_recipients(self,
                       page=None,
                       size=None):
        """Does a GET request to /recipients.

        Retrieves paginated recipients information

        Args:
            page (int, optional): Page number
            size (int, optional): Page size

        Returns:
            ListRecipientResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.base_uri
        _query_builder += '/recipients'
        _query_parameters = {
            'page': page,
            'size': size
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, ListRecipientResponse.from_dictionary)

    def get_balance(self,
                    recipient_id):
        """Does a GET request to /recipients/{recipient_id}/balance.

        Get balance information for a recipient

        Args:
            recipient_id (string): Recipient id

        Returns:
            GetBalanceResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.base_uri
        _query_builder += '/recipients/{recipient_id}/balance'
        _query_builder = APIHelper.append_url_with_template_parameters(_query_builder, { 
            'recipient_id': recipient_id
        })
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetBalanceResponse.from_dictionary)

    def create_transfer(self,
                        recipient_id,
                        request):
        """Does a POST request to /recipients/{recipient_id}/transfers.

        Creates a transfer for a recipient

        Args:
            recipient_id (string): Recipient Id
            request (CreateTransferRequest): Transfer data

        Returns:
            GetTransferResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.base_uri
        _query_builder += '/recipients/{recipient_id}/transfers'
        _query_builder = APIHelper.append_url_with_template_parameters(_query_builder, { 
            'recipient_id': recipient_id
        })
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(request))
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetTransferResponse.from_dictionary)

    def create_recipient(self,
                         request):
        """Does a POST request to /recipients.

        Creates a new recipient

        Args:
            request (CreateRecipientRequest): Recipient data

        Returns:
            GetRecipientResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.base_uri
        _query_builder += '/recipients'
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(request))
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetRecipientResponse.from_dictionary)



# -*- coding: utf-8 -*-

"""
    mundiapi.models.get_discount_response

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
from mundiapi.api_helper import APIHelper
import mundiapi.models.get_subscription_response

class GetDiscountResponse(object):

    """Implementation of the 'GetDiscountResponse' model.

    Response object for getting a discount

    Attributes:
        id (string): TODO: type description here.
        value (float): TODO: type description here.
        discount_type (string): TODO: type description here.
        status (string): TODO: type description here.
        created_at (datetime): TODO: type description here.
        subscription (GetSubscriptionResponse): TODO: type description here.
        cycles (int): TODO: type description here.
        deleted_at (datetime): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id":'id',
        "value":'value',
        "discount_type":'discount_type',
        "status":'status',
        "created_at":'created_at',
        "subscription":'subscription',
        "cycles":'cycles',
        "deleted_at":'deleted_at'
    }

    def __init__(self,
                 id=None,
                 value=None,
                 discount_type=None,
                 status=None,
                 created_at=None,
                 subscription=None,
                 cycles=None,
                 deleted_at=None):
        """Constructor for the GetDiscountResponse class"""

        # Initialize members of the class
        self.id = id
        self.value = value
        self.discount_type = discount_type
        self.status = status
        self.created_at = APIHelper.RFC3339DateTime(created_at) if created_at else None
        self.subscription = subscription
        self.cycles = cycles
        self.deleted_at = APIHelper.RFC3339DateTime(deleted_at) if deleted_at else None


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('id')
        value = dictionary.get('value')
        discount_type = dictionary.get('discount_type')
        status = dictionary.get('status')
        created_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("created_at")).datetime if dictionary.get("created_at") else None
        subscription = mundiapi.models.get_subscription_response.GetSubscriptionResponse.from_dictionary(dictionary.get('subscription')) if dictionary.get('subscription') else None
        cycles = dictionary.get('cycles')
        deleted_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("deleted_at")).datetime if dictionary.get("deleted_at") else None

        # Return an object of this model
        return cls(id,
                   value,
                   discount_type,
                   status,
                   created_at,
                   subscription,
                   cycles,
                   deleted_at)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.create_shipping_request

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
import mundiapi.models.create_address_request

class CreateShippingRequest(object):

    """Implementation of the 'CreateShippingRequest' model.

    Shipping data

    Attributes:
        amount (int): Shipping amount
        description (string): Description
        recipient_name (string): Recipient name
        recipient_phone (string): Recipient phone number
        address_id (string): The id of the address that will be used for
            shipping
        address (CreateAddressRequest): Address data

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "amount":'amount',
        "description":'description',
        "recipient_name":'recipient_name',
        "recipient_phone":'recipient_phone',
        "address_id":'address_id',
        "address":'address'
    }

    def __init__(self,
                 amount=None,
                 description=None,
                 recipient_name=None,
                 recipient_phone=None,
                 address_id=None,
                 address=None):
        """Constructor for the CreateShippingRequest class"""

        # Initialize members of the class
        self.amount = amount
        self.description = description
        self.recipient_name = recipient_name
        self.recipient_phone = recipient_phone
        self.address_id = address_id
        self.address = address


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        amount = dictionary.get('amount')
        description = dictionary.get('description')
        recipient_name = dictionary.get('recipient_name')
        recipient_phone = dictionary.get('recipient_phone')
        address_id = dictionary.get('address_id')
        address = mundiapi.models.create_address_request.CreateAddressRequest.from_dictionary(dictionary.get('address')) if dictionary.get('address') else None

        # Return an object of this model
        return cls(amount,
                   description,
                   recipient_name,
                   recipient_phone,
                   address_id,
                   address)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.create_capture_charge_request

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""


class CreateCaptureChargeRequest(object):

    """Implementation of the 'CreateCaptureChargeRequest' model.

    Request for capturing a charge

    Attributes:
        code (string): Code for the charge. Sending this field will update the
            code send on the charge and order creation.
        amount (int): The amount that will be captured

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "code":'code',
        "amount":'amount'
    }

    def __init__(self,
                 code=None,
                 amount=None):
        """Constructor for the CreateCaptureChargeRequest class"""

        # Initialize members of the class
        self.code = code
        self.amount = amount


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        code = dictionary.get('code')
        amount = dictionary.get('amount')

        # Return an object of this model
        return cls(code,
                   amount)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.create_subscription_request

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
from mundiapi.api_helper import APIHelper
import mundiapi.models.create_customer_request
import mundiapi.models.create_card_request
import mundiapi.models.create_pricing_scheme_request
import mundiapi.models.create_subscription_item_request
import mundiapi.models.create_shipping_request
import mundiapi.models.create_discount_request
import mundiapi.models.create_setup_request

class CreateSubscriptionRequest(object):

    """Implementation of the 'CreateSubscriptionRequest' model.

    Request for creating a subcription

    Attributes:
        customer (CreateCustomerRequest): Customer
        card (CreateCardRequest): Card
        code (string): Subscription code
        payment_method (string): Payment method
        billing_type (string): Billing type
        statement_descriptor (string): Statement descriptor for credit card
            subscriptions
        description (string): Subscription description
        currency (string): Currency
        interval (string): Interval
        interval_count (int): Interval count
        pricing_scheme (CreatePricingSchemeRequest): Subscription pricing
            scheme
        items (list of CreateSubscriptionItemRequest): Subscription items
        shipping (CreateShippingRequest): Shipping
        discounts (list of CreateDiscountRequest): Discounts
        metadata (dict<object, string>): Metadata
        setup (CreateSetupRequest): Setup data
        plan_id (string): Plan id
        customer_id (string): Customer id
        card_id (string): Card id
        billing_day (int): Billing day
        installments (int): Number of installments
        start_at (datetime): Subscription start date
        minimum_price (int): Subscription minimum price
        cycles (int): Number of cycles
        card_token (string): Card token
        gateway_affiliation_id (string): Gateway Affiliation code
        quantity (int): Quantity

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "customer":'customer',
        "card":'card',
        "code":'code',
        "payment_method":'payment_method',
        "billing_type":'billing_type',
        "statement_descriptor":'statement_descriptor',
        "description":'description',
        "currency":'currency',
        "interval":'interval',
        "interval_count":'interval_count',
        "pricing_scheme":'pricing_scheme',
        "items":'items',
        "shipping":'shipping',
        "discounts":'discounts',
        "metadata":'metadata',
        "setup":'setup',
        "plan_id":'plan_id',
        "customer_id":'customer_id',
        "card_id":'card_id',
        "billing_day":'billing_day',
        "installments":'installments',
        "start_at":'start_at',
        "minimum_price":'minimum_price',
        "cycles":'cycles',
        "card_token":'card_token',
        "gateway_affiliation_id":'gateway_affiliation_id',
        "quantity":'quantity'
    }

    def __init__(self,
                 customer=None,
                 card=None,
                 code=None,
                 payment_method=None,
                 billing_type=None,
                 statement_descriptor=None,
                 description=None,
                 currency=None,
                 interval=None,
                 interval_count=None,
                 pricing_scheme=None,
                 items=None,
                 shipping=None,
                 discounts=None,
                 metadata=None,
                 setup=None,
                 plan_id=None,
                 customer_id=None,
                 card_id=None,
                 billing_day=None,
                 installments=None,
                 start_at=None,
                 minimum_price=None,
                 cycles=None,
                 card_token=None,
                 gateway_affiliation_id=None,
                 quantity=None):
        """Constructor for the CreateSubscriptionRequest class"""

        # Initialize members of the class
        self.customer = customer
        self.card = card
        self.code = code
        self.payment_method = payment_method
        self.billing_type = billing_type
        self.statement_descriptor = statement_descriptor
        self.description = description
        self.currency = currency
        self.interval = interval
        self.interval_count = interval_count
        self.pricing_scheme = pricing_scheme
        self.items = items
        self.shipping = shipping
        self.discounts = discounts
        self.metadata = metadata
        self.setup = setup
        self.plan_id = plan_id
        self.customer_id = customer_id
        self.card_id = card_id
        self.billing_day = billing_day
        self.installments = installments
        self.start_at = APIHelper.RFC3339DateTime(start_at) if start_at else None
        self.minimum_price = minimum_price
        self.cycles = cycles
        self.card_token = card_token
        self.gateway_affiliation_id = gateway_affiliation_id
        self.quantity = quantity


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        customer = mundiapi.models.create_customer_request.CreateCustomerRequest.from_dictionary(dictionary.get('customer')) if dictionary.get('customer') else None
        card = mundiapi.models.create_card_request.CreateCardRequest.from_dictionary(dictionary.get('card')) if dictionary.get('card') else None
        code = dictionary.get('code')
        payment_method = dictionary.get('payment_method')
        billing_type = dictionary.get('billing_type')
        statement_descriptor = dictionary.get('statement_descriptor')
        description = dictionary.get('description')
        currency = dictionary.get('currency')
        interval = dictionary.get('interval')
        interval_count = dictionary.get('interval_count')
        pricing_scheme = mundiapi.models.create_pricing_scheme_request.CreatePricingSchemeRequest.from_dictionary(dictionary.get('pricing_scheme')) if dictionary.get('pricing_scheme') else None
        items = None
        if dictionary.get('items') != None:
            items = list()
            for structure in dictionary.get('items'):
                items.append(mundiapi.models.create_subscription_item_request.CreateSubscriptionItemRequest.from_dictionary(structure))
        shipping = mundiapi.models.create_shipping_request.CreateShippingRequest.from_dictionary(dictionary.get('shipping')) if dictionary.get('shipping') else None
        discounts = None
        if dictionary.get('discounts') != None:
            discounts = list()
            for structure in dictionary.get('discounts'):
                discounts.append(mundiapi.models.create_discount_request.CreateDiscountRequest.from_dictionary(structure))
        metadata = dictionary.get('metadata')
        setup = mundiapi.models.create_setup_request.CreateSetupRequest.from_dictionary(dictionary.get('setup')) if dictionary.get('setup') else None
        plan_id = dictionary.get('plan_id')
        customer_id = dictionary.get('customer_id')
        card_id = dictionary.get('card_id')
        billing_day = dictionary.get('billing_day')
        installments = dictionary.get('installments')
        start_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("start_at")).datetime if dictionary.get("start_at") else None
        minimum_price = dictionary.get('minimum_price')
        cycles = dictionary.get('cycles')
        card_token = dictionary.get('card_token')
        gateway_affiliation_id = dictionary.get('gateway_affiliation_id')
        quantity = dictionary.get('quantity')

        # Return an object of this model
        return cls(customer,
                   card,
                   code,
                   payment_method,
                   billing_type,
                   statement_descriptor,
                   description,
                   currency,
                   interval,
                   interval_count,
                   pricing_scheme,
                   items,
                   shipping,
                   discounts,
                   metadata,
                   setup,
                   plan_id,
                   customer_id,
                   card_id,
                   billing_day,
                   installments,
                   start_at,
                   minimum_price,
                   cycles,
                   card_token,
                   gateway_affiliation_id,
                   quantity)





__all__ = [
    'get_checkout_boleto_payment_response',
    'get_checkout_card_payment_response',
    'get_checkout_card_installment_options_response',
    'create_cancel_charge_request',
    'update_subscription_billing_date_request',
    'list_subscription_items_response',
    'list_usages_response',
    'update_subscription_payment_method_request',
    'create_card_options_request',
    'update_subscription_card_request',
    'list_order_response',
    'create_usage_request',
    'update_charge_due_date_request',
    'create_cancel_subscription_request',
    'list_transactions_response',
    'list_charges_response',
    'list_invoices_response',
    'list_subscriptions_response',
    'list_plans_response',
    'list_addresses_response',
    'list_cards_response',
    'list_customers_response',
    'paging_response',
    'create_subscription_request',
    'get_order_response',
    'create_charge_request',
    'update_card_request',
    'update_plan_item_request',
    'update_subscription_item_request',
    'create_plan_item_request',
    'create_access_token_request',
    'create_shipping_request',
    'update_plan_request',
    'get_transaction_response',
    'get_card_response',
    'get_address_response',
    'get_charge_response',
    'get_pricing_scheme_response',
    'get_discount_response',
    'create_price_bracket_request',
    'get_price_bracket_response',
    'get_customer_response',
    'create_discount_request',
    'get_shipping_response',
    'create_setup_request',
    'get_setup_response',
    'get_subscription_response',
    'create_address_request',
    'create_card_request',
    'create_plan_request',
    'create_pricing_scheme_request',
    'update_pricing_scheme_request',
    'update_price_bracket_request',
    'update_charge_card_request',
    'update_charge_payment_method_request',
    'get_period_response',
    'get_plan_item_response',
    'get_plan_response',
    'create_phone_request',
    'create_phones_request',
    'get_phone_response',
    'get_phones_response',
    'create_voucher_payment_request',
    'create_capture_charge_request',
    'create_bank_transfer_payment_request',
    'get_access_token_response',
    'list_access_tokens_response',
    'create_customer_request',
    'create_token_request',
    'create_card_token_request',
    'get_card_token_response',
    'get_token_response',
    'update_metadata_request',
    'create_payment_request',
    'create_order_request',
    'create_checkout_card_installment_option_request',
    'create_checkout_boleto_payment_request',
    'create_checkout_card_payment_request',
    'get_checkout_payment_settings_response',
    'create_seller_request',
    'get_seller_response',
    'create_order_item_request',
    'get_order_item_response',
    'create_transfer_request',
    'get_transfer_response',
    'create_recipient_request',
    'create_bank_account_request',
    'get_recipient_response',
    'get_bank_account_response',
    'update_recipient_request',
    'get_gateway_recipient_response',
    'list_recipient_response',
    'update_recipient_bank_account_request',
    'list_transfer_response',
    'get_balance_response',
    'get_anticipation_response',
    'create_anticipation_request',
    'list_anticipation_response',
    'get_anticipation_limit_response',
    'get_anticipation_limits_response',
    'create_split_request',
    'get_split_response',
    'get_device_response',
    'create_device_request',
    'get_location_response',
    'create_location_request',
    'get_invoice_response',
    'update_subscription_affiliation_id_request',
    'update_invoice_status_request',
    'get_billing_address_response',
    'update_address_request',
    'create_subscription_item_request',
    'get_subscription_item_response',
    'update_order_status_request',
    'update_order_item_request',
    'get_sellers_request',
    'update_seller_request',
    'list_seller_response',
    'get_usage_response',
    'update_customer_request',
    'get_checkout_payment_response',
    'create_checkout_payment_request',
    'create_boleto_payment_request',
    'get_invoice_item_response',
    'create_credit_card_payment_request',
    'list_discounts_response',
]


# -*- coding: utf-8 -*-

"""
    mundiapi.controllers.sellers_controller

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from .base_controller import BaseController
from ..api_helper import APIHelper
from ..configuration import Configuration
from ..http.auth.basic_auth import BasicAuth
from ..models.get_seller_response import GetSellerResponse
from ..models.list_seller_response import ListSellerResponse

class SellersController(BaseController):

    """A Controller to access Endpoints in the mundiapi API."""


    def get_seller_by_id(self,
                         id):
        """Does a GET request to /sellers/{id}.

        TODO: type endpoint description here.

        Args:
            id (string): Seller Id

        Returns:
            GetSellerResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.base_uri
        _query_builder += '/sellers/{id}'
        _query_builder = APIHelper.append_url_with_template_parameters(_query_builder, { 
            'id': id
        })
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetSellerResponse.from_dictionary)

    def delete_seller(self,
                      seller_id):
        """Does a DELETE request to /sellers/{sellerId}.

        TODO: type endpoint description here.

        Args:
            seller_id (string): Seller Id

        Returns:
            GetSellerResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.base_uri
        _query_builder += '/sellers/{sellerId}'
        _query_builder = APIHelper.append_url_with_template_parameters(_query_builder, { 
            'sellerId': seller_id
        })
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.delete(_query_url, headers=_headers)
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetSellerResponse.from_dictionary)

    def create_seller(self,
                      request):
        """Does a POST request to /sellers/.

        TODO: type endpoint description here.

        Args:
            request (CreateSellerRequest): Seller Model

        Returns:
            GetSellerResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.base_uri
        _query_builder += '/sellers/'
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(request))
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetSellerResponse.from_dictionary)

    def get_sellers(self,
                    page=None,
                    size=None,
                    name=None,
                    document=None,
                    code=None,
                    status=None,
                    mtype=None,
                    created_since=None,
                    created_until=None):
        """Does a GET request to /sellers.

        TODO: type endpoint description here.

        Args:
            page (int, optional): Page number
            size (int, optional): Page size
            name (string, optional): TODO: type description here. Example: 
            document (string, optional): TODO: type description here. Example:
                            code (string, optional): TODO: type description here. Example: 
            status (string, optional): TODO: type description here. Example: 
            mtype (string, optional): TODO: type description here. Example: 
            created_since (datetime, optional): TODO: type description here.
                Example: 
            created_until (datetime, optional): TODO: type description here.
                Example: 

        Returns:
            ListSellerResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.base_uri
        _query_builder += '/sellers'
        _query_parameters = {
            'page': page,
            'size': size,
            'name': name,
            'document': document,
            'code': code,
            'status': status,
            'type': mtype,
            'created_Since': APIHelper.RFC3339DateTime(created_since),
            'created_Until': APIHelper.RFC3339DateTime(created_until)
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, ListSellerResponse.from_dictionary)

    def update_seller(self,
                      id,
                      request):
        """Does a PUT request to /sellers/{id}.

        TODO: type endpoint description here.

        Args:
            id (string): TODO: type description here. Example: 
            request (UpdateSellerRequest): Update Seller model

        Returns:
            GetSellerResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.base_uri
        _query_builder += '/sellers/{id}'
        _query_builder = APIHelper.append_url_with_template_parameters(_query_builder, { 
            'id': id
        })
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(request))
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetSellerResponse.from_dictionary)

    def update_seller_metadata(self,
                               seller_id,
                               request):
        """Does a PATCH request to /sellers/{seller_id}/metadata.

        TODO: type endpoint description here.

        Args:
            seller_id (string): Seller Id
            request (UpdateMetadataRequest): Request for updating the charge
                metadata

        Returns:
            GetSellerResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.base_uri
        _query_builder += '/sellers/{seller_id}/metadata'
        _query_builder = APIHelper.append_url_with_template_parameters(_query_builder, { 
            'seller_id': seller_id
        })
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.patch(_query_url, headers=_headers, parameters=APIHelper.json_serialize(request))
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetSellerResponse.from_dictionary)



# -*- coding: utf-8 -*-

"""
    mundiapi.models.get_gateway_recipient_response

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""


class GetGatewayRecipientResponse(object):

    """Implementation of the 'GetGatewayRecipientResponse' model.

    Information about the recipient on the gateway

    Attributes:
        gateway (string): Gateway name
        status (string): Status of the recipient on the gateway
        pgid (string): Recipient id on the gateway
        created_at (string): Creation date
        updated_at (string): Last update date

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "gateway":'gateway',
        "status":'status',
        "pgid":'pgid',
        "created_at":'created_at',
        "updated_at":'updated_at'
    }

    def __init__(self,
                 gateway=None,
                 status=None,
                 pgid=None,
                 created_at=None,
                 updated_at=None):
        """Constructor for the GetGatewayRecipientResponse class"""

        # Initialize members of the class
        self.gateway = gateway
        self.status = status
        self.pgid = pgid
        self.created_at = created_at
        self.updated_at = updated_at


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        gateway = dictionary.get('gateway')
        status = dictionary.get('status')
        pgid = dictionary.get('pgid')
        created_at = dictionary.get('created_at')
        updated_at = dictionary.get('updated_at')

        # Return an object of this model
        return cls(gateway,
                   status,
                   pgid,
                   created_at,
                   updated_at)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.get_anticipation_limits_response

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
import mundiapi.models.get_anticipation_limit_response

class GetAnticipationLimitsResponse(object):

    """Implementation of the 'GetAnticipationLimitsResponse' model.

    Anticipation limits

    Attributes:
        max (GetAnticipationLimitResponse): Max limit
        min (GetAnticipationLimitResponse): Min limit

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "max":'max',
        "min":'min'
    }

    def __init__(self,
                 max=None,
                 min=None):
        """Constructor for the GetAnticipationLimitsResponse class"""

        # Initialize members of the class
        self.max = max
        self.min = min


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        max = mundiapi.models.get_anticipation_limit_response.GetAnticipationLimitResponse.from_dictionary(dictionary.get('max')) if dictionary.get('max') else None
        min = mundiapi.models.get_anticipation_limit_response.GetAnticipationLimitResponse.from_dictionary(dictionary.get('min')) if dictionary.get('min') else None

        # Return an object of this model
        return cls(max,
                   min)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.update_subscription_affiliation_id_request

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""


class UpdateSubscriptionAffiliationIdRequest(object):

    """Implementation of the 'UpdateSubscriptionAffiliationIdRequest' model.

    Request for updating a Subscription Affiliation Id

    Attributes:
        gateway_affiliation_id (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "gateway_affiliation_id":'gateway_affiliation_id'
    }

    def __init__(self,
                 gateway_affiliation_id=None):
        """Constructor for the UpdateSubscriptionAffiliationIdRequest class"""

        # Initialize members of the class
        self.gateway_affiliation_id = gateway_affiliation_id


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        gateway_affiliation_id = dictionary.get('gateway_affiliation_id')

        # Return an object of this model
        return cls(gateway_affiliation_id)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.get_anticipation_response

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
from mundiapi.api_helper import APIHelper
import mundiapi.models.get_recipient_response

class GetAnticipationResponse(object):

    """Implementation of the 'GetAnticipationResponse' model.

    Anticipation

    Attributes:
        id (string): Id
        requested_amount (int): Requested amount
        approved_amount (int): Approved amount
        recipient (GetRecipientResponse): Recipient
        pgid (string): Anticipation id on the gateway
        created_at (datetime): Creation date
        updated_at (datetime): Last update date
        payment_date (datetime): Payment date
        status (string): Status
        timeframe (string): Timeframe

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id":'id',
        "requested_amount":'requested_amount',
        "approved_amount":'approved_amount',
        "recipient":'recipient',
        "pgid":'pgid',
        "created_at":'created_at',
        "updated_at":'updated_at',
        "payment_date":'payment_date',
        "status":'status',
        "timeframe":'timeframe'
    }

    def __init__(self,
                 id=None,
                 requested_amount=None,
                 approved_amount=None,
                 recipient=None,
                 pgid=None,
                 created_at=None,
                 updated_at=None,
                 payment_date=None,
                 status=None,
                 timeframe=None):
        """Constructor for the GetAnticipationResponse class"""

        # Initialize members of the class
        self.id = id
        self.requested_amount = requested_amount
        self.approved_amount = approved_amount
        self.recipient = recipient
        self.pgid = pgid
        self.created_at = APIHelper.RFC3339DateTime(created_at) if created_at else None
        self.updated_at = APIHelper.RFC3339DateTime(updated_at) if updated_at else None
        self.payment_date = APIHelper.RFC3339DateTime(payment_date) if payment_date else None
        self.status = status
        self.timeframe = timeframe


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('id')
        requested_amount = dictionary.get('requested_amount')
        approved_amount = dictionary.get('approved_amount')
        recipient = mundiapi.models.get_recipient_response.GetRecipientResponse.from_dictionary(dictionary.get('recipient')) if dictionary.get('recipient') else None
        pgid = dictionary.get('pgid')
        created_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("created_at")).datetime if dictionary.get("created_at") else None
        updated_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("updated_at")).datetime if dictionary.get("updated_at") else None
        payment_date = APIHelper.RFC3339DateTime.from_value(dictionary.get("payment_date")).datetime if dictionary.get("payment_date") else None
        status = dictionary.get('status')
        timeframe = dictionary.get('timeframe')

        # Return an object of this model
        return cls(id,
                   requested_amount,
                   approved_amount,
                   recipient,
                   pgid,
                   created_at,
                   updated_at,
                   payment_date,
                   status,
                   timeframe)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.create_anticipation_request

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
from mundiapi.api_helper import APIHelper

class CreateAnticipationRequest(object):

    """Implementation of the 'CreateAnticipationRequest' model.

    Request for creating an anticipation

    Attributes:
        amount (int): Amount requested for the anticipation
        timeframe (string): Timeframe
        payment_date (datetime): Payment date

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "amount":'amount',
        "timeframe":'timeframe',
        "payment_date":'payment_date'
    }

    def __init__(self,
                 amount=None,
                 timeframe=None,
                 payment_date=None):
        """Constructor for the CreateAnticipationRequest class"""

        # Initialize members of the class
        self.amount = amount
        self.timeframe = timeframe
        self.payment_date = APIHelper.RFC3339DateTime(payment_date) if payment_date else None


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        amount = dictionary.get('amount')
        timeframe = dictionary.get('timeframe')
        payment_date = APIHelper.RFC3339DateTime.from_value(dictionary.get("payment_date")).datetime if dictionary.get("payment_date") else None

        # Return an object of this model
        return cls(amount,
                   timeframe,
                   payment_date)





# -*- coding: utf-8 -*-

"""
    mundiapi.controllers.charges_controller

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from .base_controller import BaseController
from ..api_helper import APIHelper
from ..configuration import Configuration
from ..http.auth.basic_auth import BasicAuth
from ..models.get_charge_response import GetChargeResponse
from ..models.list_charges_response import ListChargesResponse

class ChargesController(BaseController):

    """A Controller to access Endpoints in the mundiapi API."""


    def update_charge_card(self,
                           charge_id,
                           request):
        """Does a PATCH request to /charges/{charge_id}/card.

        Updates the card from a charge

        Args:
            charge_id (string): Charge id
            request (UpdateChargeCardRequest): Request for updating a charge's
                card

        Returns:
            GetChargeResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.base_uri
        _query_builder += '/charges/{charge_id}/card'
        _query_builder = APIHelper.append_url_with_template_parameters(_query_builder, { 
            'charge_id': charge_id
        })
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.patch(_query_url, headers=_headers, parameters=APIHelper.json_serialize(request))
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetChargeResponse.from_dictionary)

    def update_charge_payment_method(self,
                                     charge_id,
                                     request):
        """Does a PATCH request to /charges/{charge_id}/payment-method.

        Updates a charge's payment method

        Args:
            charge_id (string): Charge id
            request (UpdateChargePaymentMethodRequest): Request for updating
                the payment method from a charge

        Returns:
            GetChargeResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.base_uri
        _query_builder += '/charges/{charge_id}/payment-method'
        _query_builder = APIHelper.append_url_with_template_parameters(_query_builder, { 
            'charge_id': charge_id
        })
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.patch(_query_url, headers=_headers, parameters=APIHelper.json_serialize(request))
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetChargeResponse.from_dictionary)

    def create_charge(self,
                      request):
        """Does a POST request to /Charges.

        Creates a new charge

        Args:
            request (CreateChargeRequest): Request for creating a charge

        Returns:
            GetChargeResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.base_uri
        _query_builder += '/Charges'
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(request))
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetChargeResponse.from_dictionary)

    def get_charge(self,
                   charge_id):
        """Does a GET request to /charges/{charge_id}.

        Get a charge from its id

        Args:
            charge_id (string): Charge id

        Returns:
            GetChargeResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.base_uri
        _query_builder += '/charges/{charge_id}'
        _query_builder = APIHelper.append_url_with_template_parameters(_query_builder, { 
            'charge_id': charge_id
        })
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetChargeResponse.from_dictionary)

    def retry_charge(self,
                     charge_id):
        """Does a POST request to /charges/{charge_id}/retry.

        Retries a charge

        Args:
            charge_id (string): Charge id

        Returns:
            GetChargeResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.base_uri
        _query_builder += '/charges/{charge_id}/retry'
        _query_builder = APIHelper.append_url_with_template_parameters(_query_builder, { 
            'charge_id': charge_id
        })
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers)
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetChargeResponse.from_dictionary)

    def get_charges(self,
                    page=None,
                    size=None,
                    code=None,
                    status=None,
                    payment_method=None,
                    customer_id=None,
                    order_id=None,
                    created_since=None,
                    created_until=None):
        """Does a GET request to /charges.

        Lists all charges

        Args:
            page (int, optional): Page number
            size (int, optional): Page size
            code (string, optional): Filter for charge's code
            status (string, optional): Filter for charge's status
            payment_method (string, optional): Filter for charge's payment
                method
            customer_id (string, optional): Filter for charge's customer id
            order_id (string, optional): Filter for charge's order id
            created_since (datetime, optional): Filter for the beginning of
                the range for charge's creation
            created_until (datetime, optional): Filter for the end of the
                range for charge's creation

        Returns:
            ListChargesResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.base_uri
        _query_builder += '/charges'
        _query_parameters = {
            'page': page,
            'size': size,
            'code': code,
            'status': status,
            'payment_method': payment_method,
            'customer_id': customer_id,
            'order_id': order_id,
            'created_since': APIHelper.RFC3339DateTime(created_since),
            'created_until': APIHelper.RFC3339DateTime(created_until)
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.http_client.get(_query_url, headers=_headers)
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, ListChargesResponse.from_dictionary)

    def update_charge_metadata(self,
                               charge_id,
                               request):
        """Does a PATCH request to /Charges/{charge_id}/metadata.

        Updates the metadata from a charge

        Args:
            charge_id (string): The charge id
            request (UpdateMetadataRequest): Request for updating the charge
                metadata

        Returns:
            GetChargeResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.base_uri
        _query_builder += '/Charges/{charge_id}/metadata'
        _query_builder = APIHelper.append_url_with_template_parameters(_query_builder, { 
            'charge_id': charge_id
        })
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.patch(_query_url, headers=_headers, parameters=APIHelper.json_serialize(request))
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetChargeResponse.from_dictionary)

    def cancel_charge(self,
                      charge_id,
                      request=None):
        """Does a DELETE request to /charges/{charge_id}.

        Cancel a charge

        Args:
            charge_id (string): Charge id
            request (CreateCancelChargeRequest, optional): Request for
                cancelling a charge

        Returns:
            GetChargeResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.base_uri
        _query_builder += '/charges/{charge_id}'
        _query_builder = APIHelper.append_url_with_template_parameters(_query_builder, { 
            'charge_id': charge_id
        })
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.delete(_query_url, headers=_headers, parameters=APIHelper.json_serialize(request))
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetChargeResponse.from_dictionary)

    def capture_charge(self,
                       charge_id,
                       request=None):
        """Does a POST request to /charges/{charge_id}/capture.

        Captures a charge

        Args:
            charge_id (string): Charge id
            request (CreateCaptureChargeRequest, optional): Request for
                capturing a charge

        Returns:
            GetChargeResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.base_uri
        _query_builder += '/charges/{charge_id}/capture'
        _query_builder = APIHelper.append_url_with_template_parameters(_query_builder, { 
            'charge_id': charge_id
        })
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(request))
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetChargeResponse.from_dictionary)

    def update_charge_due_date(self,
                               charge_id,
                               request):
        """Does a PATCH request to /Charges/{charge_id}/due-date.

        Updates the due date from a charge

        Args:
            charge_id (string): Charge Id
            request (UpdateChargeDueDateRequest): Request for updating the due
                date

        Returns:
            GetChargeResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.base_uri
        _query_builder += '/Charges/{charge_id}/due-date'
        _query_builder = APIHelper.append_url_with_template_parameters(_query_builder, { 
            'charge_id': charge_id
        })
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.patch(_query_url, headers=_headers, parameters=APIHelper.json_serialize(request))
        BasicAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, GetChargeResponse.from_dictionary)



# -*- coding: utf-8 -*-

"""
    mundiapi.models.get_card_response

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
from mundiapi.api_helper import APIHelper
import mundiapi.models.get_billing_address_response
import mundiapi.models.get_customer_response

class GetCardResponse(object):

    """Implementation of the 'GetCardResponse' model.

    Response object for getting a credit card

    Attributes:
        id (string): TODO: type description here.
        last_four_digits (string): TODO: type description here.
        brand (string): TODO: type description here.
        holder_name (string): TODO: type description here.
        exp_month (int): TODO: type description here.
        exp_year (int): TODO: type description here.
        status (string): TODO: type description here.
        created_at (datetime): TODO: type description here.
        updated_at (datetime): TODO: type description here.
        billing_address (GetBillingAddressResponse): TODO: type description
            here.
        customer (GetCustomerResponse): TODO: type description here.
        metadata (dict<object, string>): TODO: type description here.
        mtype (string): Card type
        holder_document (string): Document number for the card's holder
        deleted_at (datetime): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id":'id',
        "last_four_digits":'last_four_digits',
        "brand":'brand',
        "holder_name":'holder_name',
        "exp_month":'exp_month',
        "exp_year":'exp_year',
        "status":'status',
        "created_at":'created_at',
        "updated_at":'updated_at',
        "billing_address":'billing_address',
        "customer":'customer',
        "metadata":'metadata',
        "mtype":'type',
        "holder_document":'holder_document',
        "deleted_at":'deleted_at'
    }

    def __init__(self,
                 id=None,
                 last_four_digits=None,
                 brand=None,
                 holder_name=None,
                 exp_month=None,
                 exp_year=None,
                 status=None,
                 created_at=None,
                 updated_at=None,
                 billing_address=None,
                 customer=None,
                 metadata=None,
                 mtype=None,
                 holder_document=None,
                 deleted_at=None):
        """Constructor for the GetCardResponse class"""

        # Initialize members of the class
        self.id = id
        self.last_four_digits = last_four_digits
        self.brand = brand
        self.holder_name = holder_name
        self.exp_month = exp_month
        self.exp_year = exp_year
        self.status = status
        self.created_at = APIHelper.RFC3339DateTime(created_at) if created_at else None
        self.updated_at = APIHelper.RFC3339DateTime(updated_at) if updated_at else None
        self.billing_address = billing_address
        self.customer = customer
        self.metadata = metadata
        self.mtype = mtype
        self.holder_document = holder_document
        self.deleted_at = APIHelper.RFC3339DateTime(deleted_at) if deleted_at else None


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('id')
        last_four_digits = dictionary.get('last_four_digits')
        brand = dictionary.get('brand')
        holder_name = dictionary.get('holder_name')
        exp_month = dictionary.get('exp_month')
        exp_year = dictionary.get('exp_year')
        status = dictionary.get('status')
        created_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("created_at")).datetime if dictionary.get("created_at") else None
        updated_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("updated_at")).datetime if dictionary.get("updated_at") else None
        billing_address = mundiapi.models.get_billing_address_response.GetBillingAddressResponse.from_dictionary(dictionary.get('billing_address')) if dictionary.get('billing_address') else None
        customer = mundiapi.models.get_customer_response.GetCustomerResponse.from_dictionary(dictionary.get('customer')) if dictionary.get('customer') else None
        metadata = dictionary.get('metadata')
        mtype = dictionary.get('type')
        holder_document = dictionary.get('holder_document')
        deleted_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("deleted_at")).datetime if dictionary.get("deleted_at") else None

        # Return an object of this model
        return cls(id,
                   last_four_digits,
                   brand,
                   holder_name,
                   exp_month,
                   exp_year,
                   status,
                   created_at,
                   updated_at,
                   billing_address,
                   customer,
                   metadata,
                   mtype,
                   holder_document,
                   deleted_at)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.update_recipient_request

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""


class UpdateRecipientRequest(object):

    """Implementation of the 'UpdateRecipientRequest' model.

    Request for updating a Recipient

    Attributes:
        name (string): Name
        email (string): Email
        description (string): Description
        mtype (string): Type
        status (string): Status
        metadata (dict<object, string>): Metadata

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name":'name',
        "email":'email',
        "description":'description',
        "mtype":'type',
        "status":'status',
        "metadata":'metadata'
    }

    def __init__(self,
                 name=None,
                 email=None,
                 description=None,
                 mtype=None,
                 status=None,
                 metadata=None):
        """Constructor for the UpdateRecipientRequest class"""

        # Initialize members of the class
        self.name = name
        self.email = email
        self.description = description
        self.mtype = mtype
        self.status = status
        self.metadata = metadata


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get('name')
        email = dictionary.get('email')
        description = dictionary.get('description')
        mtype = dictionary.get('type')
        status = dictionary.get('status')
        metadata = dictionary.get('metadata')

        # Return an object of this model
        return cls(name,
                   email,
                   description,
                   mtype,
                   status,
                   metadata)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.get_invoice_item_response

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
import mundiapi.models.get_pricing_scheme_response
import mundiapi.models.get_price_bracket_response

class GetInvoiceItemResponse(object):

    """Implementation of the 'GetInvoiceItemResponse' model.

    Response object for getting an invoice item

    Attributes:
        amount (int): TODO: type description here.
        description (string): TODO: type description here.
        pricing_scheme (GetPricingSchemeResponse): TODO: type description
            here.
        price_bracket (GetPriceBracketResponse): TODO: type description here.
        subscription_item_id (string): Subscription Item Id
        quantity (int): TODO: type description here.
        name (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "amount":'amount',
        "description":'description',
        "pricing_scheme":'pricing_scheme',
        "price_bracket":'price_bracket',
        "subscription_item_id":'subscription_item_id',
        "quantity":'quantity',
        "name":'name'
    }

    def __init__(self,
                 amount=None,
                 description=None,
                 pricing_scheme=None,
                 price_bracket=None,
                 subscription_item_id=None,
                 quantity=None,
                 name=None):
        """Constructor for the GetInvoiceItemResponse class"""

        # Initialize members of the class
        self.amount = amount
        self.description = description
        self.pricing_scheme = pricing_scheme
        self.price_bracket = price_bracket
        self.subscription_item_id = subscription_item_id
        self.quantity = quantity
        self.name = name


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        amount = dictionary.get('amount')
        description = dictionary.get('description')
        pricing_scheme = mundiapi.models.get_pricing_scheme_response.GetPricingSchemeResponse.from_dictionary(dictionary.get('pricing_scheme')) if dictionary.get('pricing_scheme') else None
        price_bracket = mundiapi.models.get_price_bracket_response.GetPriceBracketResponse.from_dictionary(dictionary.get('price_bracket')) if dictionary.get('price_bracket') else None
        subscription_item_id = dictionary.get('subscription_item_id')
        quantity = dictionary.get('quantity')
        name = dictionary.get('name')

        # Return an object of this model
        return cls(amount,
                   description,
                   pricing_scheme,
                   price_bracket,
                   subscription_item_id,
                   quantity,
                   name)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.create_access_token_request

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""


class CreateAccessTokenRequest(object):

    """Implementation of the 'CreateAccessTokenRequest' model.

    Request for creating a new Access Token

    Attributes:
        expires_in (int): Minutes to expire the token

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "expires_in":'expires_in'
    }

    def __init__(self,
                 expires_in=None):
        """Constructor for the CreateAccessTokenRequest class"""

        # Initialize members of the class
        self.expires_in = expires_in


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        expires_in = dictionary.get('expires_in')

        # Return an object of this model
        return cls(expires_in)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.create_charge_request

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
from mundiapi.api_helper import APIHelper
import mundiapi.models.create_customer_request
import mundiapi.models.create_payment_request

class CreateChargeRequest(object):

    """Implementation of the 'CreateChargeRequest' model.

    Request for creating a new charge

    Attributes:
        code (string): Code
        amount (int): The amount of the charge, in cents
        customer_id (string): The customer's id
        customer (CreateCustomerRequest): Customer data
        payment (CreatePaymentRequest): Payment data
        metadata (dict<object, string>): Metadata
        due_at (datetime): The charge due date

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "code":'code',
        "amount":'amount',
        "customer_id":'customer_id',
        "customer":'customer',
        "payment":'payment',
        "metadata":'metadata',
        "due_at":'due_at'
    }

    def __init__(self,
                 code=None,
                 amount=None,
                 customer_id=None,
                 customer=None,
                 payment=None,
                 metadata=None,
                 due_at=None):
        """Constructor for the CreateChargeRequest class"""

        # Initialize members of the class
        self.code = code
        self.amount = amount
        self.customer_id = customer_id
        self.customer = customer
        self.payment = payment
        self.metadata = metadata
        self.due_at = APIHelper.RFC3339DateTime(due_at) if due_at else None


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        code = dictionary.get('code')
        amount = dictionary.get('amount')
        customer_id = dictionary.get('customer_id')
        customer = mundiapi.models.create_customer_request.CreateCustomerRequest.from_dictionary(dictionary.get('customer')) if dictionary.get('customer') else None
        payment = mundiapi.models.create_payment_request.CreatePaymentRequest.from_dictionary(dictionary.get('payment')) if dictionary.get('payment') else None
        metadata = dictionary.get('metadata')
        due_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("due_at")).datetime if dictionary.get("due_at") else None

        # Return an object of this model
        return cls(code,
                   amount,
                   customer_id,
                   customer,
                   payment,
                   metadata,
                   due_at)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.update_recipient_bank_account_request

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
import mundiapi.models.create_bank_account_request

class UpdateRecipientBankAccountRequest(object):

    """Implementation of the 'UpdateRecipientBankAccountRequest' model.

    Updates the default bank account for a recipient

    Attributes:
        bank_account (CreateBankAccountRequest): Bank account

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "bank_account":'bank_account'
    }

    def __init__(self,
                 bank_account=None):
        """Constructor for the UpdateRecipientBankAccountRequest class"""

        # Initialize members of the class
        self.bank_account = bank_account


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        bank_account = mundiapi.models.create_bank_account_request.CreateBankAccountRequest.from_dictionary(dictionary.get('bank_account')) if dictionary.get('bank_account') else None

        # Return an object of this model
        return cls(bank_account)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.get_order_response

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
from mundiapi.api_helper import APIHelper
import mundiapi.models.get_order_item_response
import mundiapi.models.get_customer_response
import mundiapi.models.get_charge_response
import mundiapi.models.get_shipping_response
import mundiapi.models.get_checkout_payment_response
import mundiapi.models.get_location_response
import mundiapi.models.get_device_response

class GetOrderResponse(object):

    """Implementation of the 'GetOrderResponse' model.

    Response object for getting an Order

    Attributes:
        id (string): TODO: type description here.
        code (string): TODO: type description here.
        currency (string): TODO: type description here.
        items (list of GetOrderItemResponse): TODO: type description here.
        customer (GetCustomerResponse): TODO: type description here.
        status (string): TODO: type description here.
        created_at (datetime): TODO: type description here.
        updated_at (datetime): TODO: type description here.
        charges (list of GetChargeResponse): TODO: type description here.
        invoice_url (string): TODO: type description here.
        shipping (GetShippingResponse): TODO: type description here.
        metadata (dict<object, string>): TODO: type description here.
        closed (bool): Indicates whether the order is closed
        checkouts (list of GetCheckoutPaymentResponse): Checkout Payment
            Settings Response
        ip (string): Ip address
        session_id (string): Session id
        location (GetLocationResponse): Location
        device (GetDeviceResponse): Device's informations

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id":'id',
        "code":'code',
        "currency":'currency',
        "items":'items',
        "customer":'customer',
        "status":'status',
        "created_at":'created_at',
        "updated_at":'updated_at',
        "charges":'charges',
        "invoice_url":'invoice_url',
        "shipping":'shipping',
        "metadata":'metadata',
        "closed":'closed',
        "checkouts":'checkouts',
        "ip":'ip',
        "session_id":'session_id',
        "location":'location',
        "device":'device'
    }

    def __init__(self,
                 id=None,
                 code=None,
                 currency=None,
                 items=None,
                 customer=None,
                 status=None,
                 created_at=None,
                 updated_at=None,
                 charges=None,
                 invoice_url=None,
                 shipping=None,
                 metadata=None,
                 closed=None,
                 checkouts=None,
                 ip=None,
                 session_id=None,
                 location=None,
                 device=None):
        """Constructor for the GetOrderResponse class"""

        # Initialize members of the class
        self.id = id
        self.code = code
        self.currency = currency
        self.items = items
        self.customer = customer
        self.status = status
        self.created_at = APIHelper.RFC3339DateTime(created_at) if created_at else None
        self.updated_at = APIHelper.RFC3339DateTime(updated_at) if updated_at else None
        self.charges = charges
        self.invoice_url = invoice_url
        self.shipping = shipping
        self.metadata = metadata
        self.closed = closed
        self.checkouts = checkouts
        self.ip = ip
        self.session_id = session_id
        self.location = location
        self.device = device


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('id')
        code = dictionary.get('code')
        currency = dictionary.get('currency')
        items = None
        if dictionary.get('items') != None:
            items = list()
            for structure in dictionary.get('items'):
                items.append(mundiapi.models.get_order_item_response.GetOrderItemResponse.from_dictionary(structure))
        customer = mundiapi.models.get_customer_response.GetCustomerResponse.from_dictionary(dictionary.get('customer')) if dictionary.get('customer') else None
        status = dictionary.get('status')
        created_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("created_at")).datetime if dictionary.get("created_at") else None
        updated_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("updated_at")).datetime if dictionary.get("updated_at") else None
        charges = None
        if dictionary.get('charges') != None:
            charges = list()
            for structure in dictionary.get('charges'):
                charges.append(mundiapi.models.get_charge_response.GetChargeResponse.from_dictionary(structure))
        invoice_url = dictionary.get('invoice_url')
        shipping = mundiapi.models.get_shipping_response.GetShippingResponse.from_dictionary(dictionary.get('shipping')) if dictionary.get('shipping') else None
        metadata = dictionary.get('metadata')
        closed = dictionary.get('closed')
        checkouts = None
        if dictionary.get('checkouts') != None:
            checkouts = list()
            for structure in dictionary.get('checkouts'):
                checkouts.append(mundiapi.models.get_checkout_payment_response.GetCheckoutPaymentResponse.from_dictionary(structure))
        ip = dictionary.get('ip')
        session_id = dictionary.get('session_id')
        location = mundiapi.models.get_location_response.GetLocationResponse.from_dictionary(dictionary.get('location')) if dictionary.get('location') else None
        device = mundiapi.models.get_device_response.GetDeviceResponse.from_dictionary(dictionary.get('device')) if dictionary.get('device') else None

        # Return an object of this model
        return cls(id,
                   code,
                   currency,
                   items,
                   customer,
                   status,
                   created_at,
                   updated_at,
                   charges,
                   invoice_url,
                   shipping,
                   metadata,
                   closed,
                   checkouts,
                   ip,
                   session_id,
                   location,
                   device)





# -*- coding: utf-8 -*-

"""
   mundiapi.configuration

   This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
from .api_helper import APIHelper

class Configuration(object):

    """A class used for configuring the SDK by a user.

    This class need not be instantiated and all properties and methods
    are accessible without instance creation.

    """

    # Set the array parameter serialization method
    # (allowed: indexed, unindexed, plain, csv, tsv, psv)
    array_serialization = "indexed"

    # The base Uri for API calls
    base_uri = 'https://api.mundipagg.com/core/v1'

    # The username to use with basic authentication
    # TODO: Set an appropriate value
    basic_auth_user_name = "TODO: Replace"

    # The password to use with basic authentication
    # TODO: Set an appropriate value
    basic_auth_password = "TODO: Replace"




# -*- coding: utf-8 -*-

"""
    mundiapi.models.get_checkout_card_payment_response

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
import mundiapi.models.get_checkout_card_installment_options_response

class GetCheckoutCardPaymentResponse(object):

    """Implementation of the 'GetCheckoutCardPaymentResponse' model.

    TODO: type model description here.

    Attributes:
        statement_descriptor (string): Descrição na fatura
        installments (list of GetCheckoutCardInstallmentOptionsResponse):
            Parcelas

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "statement_descriptor":'statementDescriptor',
        "installments":'installments'
    }

    def __init__(self,
                 statement_descriptor=None,
                 installments=None):
        """Constructor for the GetCheckoutCardPaymentResponse class"""

        # Initialize members of the class
        self.statement_descriptor = statement_descriptor
        self.installments = installments


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        statement_descriptor = dictionary.get('statementDescriptor')
        installments = None
        if dictionary.get('installments') != None:
            installments = list()
            for structure in dictionary.get('installments'):
                installments.append(mundiapi.models.get_checkout_card_installment_options_response.GetCheckoutCardInstallmentOptionsResponse.from_dictionary(structure))

        # Return an object of this model
        return cls(statement_descriptor,
                   installments)





# -*- coding: utf-8 -*-

"""
    mundiapi.mundi_api_client

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""
from .decorators import lazy_property
from .configuration import Configuration
from .controllers.subscriptions_controller import SubscriptionsController
from .controllers.orders_controller import OrdersController
from .controllers.plans_controller import PlansController
from .controllers.invoices_controller import InvoicesController
from .controllers.customers_controller import CustomersController
from .controllers.charges_controller import ChargesController
from .controllers.recipients_controller import RecipientsController
from .controllers.tokens_controller import TokensController
from .controllers.sellers_controller import SellersController

class MundiapiClient(object):

    config = Configuration

    @lazy_property
    def subscriptions(self):
        return SubscriptionsController()

    @lazy_property
    def orders(self):
        return OrdersController()

    @lazy_property
    def plans(self):
        return PlansController()

    @lazy_property
    def invoices(self):
        return InvoicesController()

    @lazy_property
    def customers(self):
        return CustomersController()

    @lazy_property
    def charges(self):
        return ChargesController()

    @lazy_property
    def recipients(self):
        return RecipientsController()

    @lazy_property
    def tokens(self):
        return TokensController()

    @lazy_property
    def sellers(self):
        return SellersController()


    def __init__(self, 
                 basic_auth_user_name = None,
                 basic_auth_password = None):
        if basic_auth_user_name != None:
            Configuration.basic_auth_user_name = basic_auth_user_name
        if basic_auth_password != None:
            Configuration.basic_auth_password = basic_auth_password





# -*- coding: utf-8 -*-

"""
    mundiapi.models.create_recipient_request

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
import mundiapi.models.create_bank_account_request

class CreateRecipientRequest(object):

    """Implementation of the 'CreateRecipientRequest' model.

    Request for creating a recipient

    Attributes:
        name (string): Recipient name
        email (string): Recipient email
        description (string): Recipient description
        document (string): Recipient document number
        mtype (string): Recipient type
        default_bank_account (CreateBankAccountRequest): Bank account
        metadata (dict<object, string>): Metadata

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name":'name',
        "email":'email',
        "description":'description',
        "document":'document',
        "mtype":'type',
        "default_bank_account":'default_bank_account',
        "metadata":'metadata'
    }

    def __init__(self,
                 name=None,
                 email=None,
                 description=None,
                 document=None,
                 mtype=None,
                 default_bank_account=None,
                 metadata=None):
        """Constructor for the CreateRecipientRequest class"""

        # Initialize members of the class
        self.name = name
        self.email = email
        self.description = description
        self.document = document
        self.mtype = mtype
        self.default_bank_account = default_bank_account
        self.metadata = metadata


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get('name')
        email = dictionary.get('email')
        description = dictionary.get('description')
        document = dictionary.get('document')
        mtype = dictionary.get('type')
        default_bank_account = mundiapi.models.create_bank_account_request.CreateBankAccountRequest.from_dictionary(dictionary.get('default_bank_account')) if dictionary.get('default_bank_account') else None
        metadata = dictionary.get('metadata')

        # Return an object of this model
        return cls(name,
                   email,
                   description,
                   document,
                   mtype,
                   default_bank_account,
                   metadata)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.update_subscription_card_request

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
import mundiapi.models.create_card_request

class UpdateSubscriptionCardRequest(object):

    """Implementation of the 'UpdateSubscriptionCardRequest' model.

    Request for updating the card from a subscription

    Attributes:
        card (CreateCardRequest): Credit card data
        card_id (string): Credit card id

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "card":'card',
        "card_id":'card_id'
    }

    def __init__(self,
                 card=None,
                 card_id=None):
        """Constructor for the UpdateSubscriptionCardRequest class"""

        # Initialize members of the class
        self.card = card
        self.card_id = card_id


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        card = mundiapi.models.create_card_request.CreateCardRequest.from_dictionary(dictionary.get('card')) if dictionary.get('card') else None
        card_id = dictionary.get('card_id')

        # Return an object of this model
        return cls(card,
                   card_id)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.create_setup_request

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
import mundiapi.models.create_payment_request

class CreateSetupRequest(object):

    """Implementation of the 'CreateSetupRequest' model.

    Request for creating a Setup for a subscription. The setup is an order
    that will be created at the subscription creation.

    Attributes:
        amount (int): Setup amount
        description (string): Description
        payment (CreatePaymentRequest): Payment data

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "amount":'amount',
        "description":'description',
        "payment":'payment'
    }

    def __init__(self,
                 amount=None,
                 description=None,
                 payment=None):
        """Constructor for the CreateSetupRequest class"""

        # Initialize members of the class
        self.amount = amount
        self.description = description
        self.payment = payment


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        amount = dictionary.get('amount')
        description = dictionary.get('description')
        payment = mundiapi.models.create_payment_request.CreatePaymentRequest.from_dictionary(dictionary.get('payment')) if dictionary.get('payment') else None

        # Return an object of this model
        return cls(amount,
                   description,
                   payment)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.create_usage_request

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
from mundiapi.api_helper import APIHelper

class CreateUsageRequest(object):

    """Implementation of the 'CreateUsageRequest' model.

    Request for creating a usage

    Attributes:
        quantity (int): TODO: type description here.
        description (string): TODO: type description here.
        used_at (datetime): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "quantity":'quantity',
        "description":'description',
        "used_at":'used_at'
    }

    def __init__(self,
                 quantity=None,
                 description=None,
                 used_at=None):
        """Constructor for the CreateUsageRequest class"""

        # Initialize members of the class
        self.quantity = quantity
        self.description = description
        self.used_at = APIHelper.RFC3339DateTime(used_at) if used_at else None


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        quantity = dictionary.get('quantity')
        description = dictionary.get('description')
        used_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("used_at")).datetime if dictionary.get("used_at") else None

        # Return an object of this model
        return cls(quantity,
                   description,
                   used_at)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.get_recipient_response

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
from mundiapi.api_helper import APIHelper
import mundiapi.models.get_bank_account_response
import mundiapi.models.get_gateway_recipient_response

class GetRecipientResponse(object):

    """Implementation of the 'GetRecipientResponse' model.

    Recipient response

    Attributes:
        id (string): Id
        name (string): Name
        email (string): Email
        document (string): Document
        description (string): Description
        mtype (string): Type
        status (string): Status
        created_at (datetime): Creation date
        updated_at (datetime): Last update date
        deleted_at (datetime): Deletion date
        default_bank_account (GetBankAccountResponse): Default bank account
        gateway_recipients (list of GetGatewayRecipientResponse): Info about
            the recipient on the gateway
        metadata (dict<object, string>): Metadata

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id":'id',
        "name":'name',
        "email":'email',
        "document":'document',
        "description":'description',
        "mtype":'type',
        "status":'status',
        "created_at":'created_at',
        "updated_at":'updated_at',
        "deleted_at":'deleted_at',
        "default_bank_account":'default_bank_account',
        "gateway_recipients":'gateway_recipients',
        "metadata":'metadata'
    }

    def __init__(self,
                 id=None,
                 name=None,
                 email=None,
                 document=None,
                 description=None,
                 mtype=None,
                 status=None,
                 created_at=None,
                 updated_at=None,
                 deleted_at=None,
                 default_bank_account=None,
                 gateway_recipients=None,
                 metadata=None):
        """Constructor for the GetRecipientResponse class"""

        # Initialize members of the class
        self.id = id
        self.name = name
        self.email = email
        self.document = document
        self.description = description
        self.mtype = mtype
        self.status = status
        self.created_at = APIHelper.RFC3339DateTime(created_at) if created_at else None
        self.updated_at = APIHelper.RFC3339DateTime(updated_at) if updated_at else None
        self.deleted_at = APIHelper.RFC3339DateTime(deleted_at) if deleted_at else None
        self.default_bank_account = default_bank_account
        self.gateway_recipients = gateway_recipients
        self.metadata = metadata


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('id')
        name = dictionary.get('name')
        email = dictionary.get('email')
        document = dictionary.get('document')
        description = dictionary.get('description')
        mtype = dictionary.get('type')
        status = dictionary.get('status')
        created_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("created_at")).datetime if dictionary.get("created_at") else None
        updated_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("updated_at")).datetime if dictionary.get("updated_at") else None
        deleted_at = APIHelper.RFC3339DateTime.from_value(dictionary.get("deleted_at")).datetime if dictionary.get("deleted_at") else None
        default_bank_account = mundiapi.models.get_bank_account_response.GetBankAccountResponse.from_dictionary(dictionary.get('default_bank_account')) if dictionary.get('default_bank_account') else None
        gateway_recipients = None
        if dictionary.get('gateway_recipients') != None:
            gateway_recipients = list()
            for structure in dictionary.get('gateway_recipients'):
                gateway_recipients.append(mundiapi.models.get_gateway_recipient_response.GetGatewayRecipientResponse.from_dictionary(structure))
        metadata = dictionary.get('metadata')

        # Return an object of this model
        return cls(id,
                   name,
                   email,
                   document,
                   description,
                   mtype,
                   status,
                   created_at,
                   updated_at,
                   deleted_at,
                   default_bank_account,
                   gateway_recipients,
                   metadata)





# -*- coding: utf-8 -*-

"""
    mundiapi.models.create_bank_account_request

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""


class CreateBankAccountRequest(object):

    """Implementation of the 'CreateBankAccountRequest' model.

    Request for creating a bank account

    Attributes:
        holder_name (string): Bank account holder name
        holder_type (string): Bank account holder type
        holder_document (string): Bank account holder document
        bank (string): Bank
        branch_number (string): Branch number
        branch_check_digit (string): Branch check digit
        account_number (string): Account number
        account_check_digit (string): Account check digit
        mtype (string): Bank account type
        metadata (dict<object, string>): Metadata

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "holder_name":'holder_name',
        "holder_type":'holder_type',
        "holder_document":'holder_document',
        "bank":'bank',
        "branch_number":'branch_number',
        "branch_check_digit":'branch_check_digit',
        "account_number":'account_number',
        "account_check_digit":'account_check_digit',
        "mtype":'type',
        "metadata":'metadata'
    }

    def __init__(self,
                 holder_name=None,
                 holder_type=None,
                 holder_document=None,
                 bank=None,
                 branch_number=None,
                 branch_check_digit=None,
                 account_number=None,
                 account_check_digit=None,
                 mtype=None,
                 metadata=None):
        """Constructor for the CreateBankAccountRequest class"""

        # Initialize members of the class
        self.holder_name = holder_name
        self.holder_type = holder_type
        self.holder_document = holder_document
        self.bank = bank
        self.branch_number = branch_number
        self.branch_check_digit = branch_check_digit
        self.account_number = account_number
        self.account_check_digit = account_check_digit
        self.mtype = mtype
        self.metadata = metadata


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        holder_name = dictionary.get('holder_name')
        holder_type = dictionary.get('holder_type')
        holder_document = dictionary.get('holder_document')
        bank = dictionary.get('bank')
        branch_number = dictionary.get('branch_number')
        branch_check_digit = dictionary.get('branch_check_digit')
        account_number = dictionary.get('account_number')
        account_check_digit = dictionary.get('account_check_digit')
        mtype = dictionary.get('type')
        metadata = dictionary.get('metadata')

        # Return an object of this model
        return cls(holder_name,
                   holder_type,
                   holder_document,
                   bank,
                   branch_number,
                   branch_check_digit,
                   account_number,
                   account_check_digit,
                   mtype,
                   metadata)


